==> matter-bootstrap-1.2.1.tgz: package/out/replication/componentsReplicate.lua <==
-- Compiled with roblox-ts v2.3.0-dev-576ad98
local TS = _G[script]
local useEvent = TS.import(script, TS.getModule(script, "@rbxts", "matter").lib).useEvent
local Object = TS.import(script, TS.getModule(script, "@rbxts", "object-utils"))
local Players = TS.import(script, TS.getModule(script, "@rbxts", "services")).Players
local MATTER_REPLICATION_ROUTE_NAME = TS.import(script, script.Parent.Parent, "constants").MATTER_REPLICATION_ROUTE_NAME
local replicatedComponentsIn = TS.import(script, script.Parent.Parent, "utils").replicatedComponentsIn
local function componentsReplicateSystemFactory(components)
	return {
		system = function(world, _, routes)
			if not routes then
				error("No routes passed to the componentsReplicate system! Cannot proceed")
			end
			local worldReplicationRoute = routes[MATTER_REPLICATION_ROUTE_NAME]
			local replicatedComponents = replicatedComponentsIn(components)
			-- Replicate the entire world to new players
			for _, player in useEvent(Players, "PlayerAdded") do
				local payload = {}
				for entityId, components in world do
					local entityPayload = {}
					for component, componentData in components do
						if not (table.find(Object.values(replicatedComponents), component) ~= nil) then
							continue
						end
						entityPayload[tostring(component)] = {
							data = componentData,
						}
					end
					payload[tostring(entityId)] = entityPayload
				end
				worldReplicationRoute:send(payload):to(player)
			end
			-- Replicate changes as needed
			local diff = {}
			local _exp = Object.values(replicatedComponents)
			-- ▼ ReadonlyArray.forEach ▼
			local _callback = function(component)
				for entityId, record in world:queryChanged(component) do
					local entityStringId = tostring(entityId)
					local componentName = tostring(component)
					if diff[entityStringId] == nil then
						diff[entityStringId] = {}
					end
					if not world:contains(entityId) and record.new ~= nil then
						continue
					end
					diff[entityStringId][componentName] = {
						data = record.new,
					}
				end
			end
			for _k, _v in _exp do
				_callback(_v, _k - 1, _exp)
			end
			-- ▲ ReadonlyArray.forEach ▲
			if not { next(diff) } then
				return nil
			end
			worldReplicationRoute:send(diff)
		end,
		priority = math.huge,
	}
end
return {
	default = componentsReplicateSystemFactory,
}

==> matter-bootstrap-1.4.0.tgz: package/out/replication/componentsReplicate.lua <==
-- Compiled with roblox-ts v2.3.0-dev-576ad98
local TS = _G[script]
local useEvent = TS.import(script, TS.getModule(script, "@rbxts", "matter").lib).useEvent
local Object = TS.import(script, TS.getModule(script, "@rbxts", "object-utils"))
local Players = TS.import(script, TS.getModule(script, "@rbxts", "services")).Players
local _constants = TS.import(script, script.Parent.Parent, "constants")
local MATTER_REPLICATION_ROUTE_NAME = _constants.MATTER_REPLICATION_ROUTE_NAME
local REPLICATED_METADATA_KEY = _constants.REPLICATED_METADATA_KEY
local decoratedComponentsIn = TS.import(script, script.Parent.Parent, "utils").decoratedComponentsIn
local function componentsReplicateSystemFactory(components)
	return {
		system = function(world, _, routes)
			if not routes then
				error("No routes passed to the componentsReplicate system! Cannot proceed")
			end
			local worldReplicationRoute = routes[MATTER_REPLICATION_ROUTE_NAME]
			local replicatedComponents = decoratedComponentsIn(components, REPLICATED_METADATA_KEY)
			-- Replicate the entire world to new players
			for _, player in useEvent(Players, "PlayerAdded") do
				local payload = {}
				for entityId, components in world do
					local entityPayload = {}
					for component, componentData in components do
						if not (table.find(Object.values(replicatedComponents), component) ~= nil) then
							continue
						end
						entityPayload[tostring(component)] = {
							data = componentData,
						}
					end
					payload[tostring(entityId)] = entityPayload
				end
				worldReplicationRoute:send(payload):to(player)
			end
			-- Replicate changes as needed
			local diff = {}
			local _exp = Object.values(replicatedComponents)
			-- ▼ ReadonlyArray.forEach ▼
			local _callback = function(component)
				for entityId, record in world:queryChanged(component) do
					local entityStringId = tostring(entityId)
					local componentName = tostring(component)
					if diff[entityStringId] == nil then
						diff[entityStringId] = {}
					end
					if not world:contains(entityId) and record.new ~= nil then
						continue
					end
					diff[entityStringId][componentName] = {
						data = record.new,
					}
				end
			end
			for _k, _v in _exp do
				_callback(_v, _k - 1, _exp)
			end
			-- ▲ ReadonlyArray.forEach ▲
			if not { next(diff) } then
				return nil
			end
			worldReplicationRoute:send(diff)
		end,
		priority = math.huge,
	}
end
return {
	default = componentsReplicateSystemFactory,
}
